@@ -1,8 +1,16 @@
-from sphinx.ext.autodoc.directive import AutodocDirective, DummyOptionSpec, DocumenterBridge
-from sphinx.ext.autodoc.directive import process_documenter_options, parse_generated_content
+from sphinx.ext.autodoc.directive import (
+    AutodocDirective,
+    DummyOptionSpec,
+    DocumenterBridge,
+)
+from sphinx.ext.autodoc.directive import (
+    process_documenter_options,
+    parse_generated_content,
+)
 import sphinx.util
 
-logger = sphinx.util.logging.getLogger('matlab-domain')
+logger = sphinx.util.logging.getLogger("matlab-domain")
+
 
 class MatlabAutodocDirective(AutodocDirective):
     """A directive class for all MATLAB autodoc directives.
@@ -13,6 +21,7 @@ class MatlabAutodocDirective(AutodocDirective):
     After the processing, it parses and returns the generated content by
     Documenter.
     """
+
     option_spec = DummyOptionSpec()
     has_content = True
     required_arguments = 1
@@ -26,29 +35,43 @@ class MatlabAutodocDirective(AutodocDirective):
             source, lineno = reporter.get_source_and_line(self.lineno)  # type: ignore
         except AttributeError:
             source, lineno = (None, None)
-        logger.debug('[sphinxcontrib-matlabdomain] %s:%s: input:\n%s', source, lineno, self.block_text)
+        logger.debug(
+            "[sphinxcontrib-matlabdomain] %s:%s: input:\n%s",
+            source,
+            lineno,
+            self.block_text,
+        )
 
         # look up target Documenter
-        objtype = self.name.replace('auto', '')  # Removes auto
+        objtype = self.name.replace("auto", "")  # Removes auto
         doccls = self.env.app.registry.documenters[objtype]
 
         # process the options with the selected documenter's option_spec
         try:
-            documenter_options = process_documenter_options(doccls, self.config, self.options)
+            documenter_options = process_documenter_options(
+                doccls, self.config, self.options
+            )
         except (KeyError, ValueError, TypeError) as exc:
             # an option is either unknown or has a wrong type
-            logger.error('An option to %s is either unknown or has an invalid value: %s' %
-                         (self.name, exc), location=(source, lineno))
+            logger.error(
+                "An option to %s is either unknown or has an invalid value: %s"
+                % (self.name, exc),
+                location=(source, lineno),
+            )
             return []
 
         # generate the output
-        params = DocumenterBridge(self.env, reporter, documenter_options, lineno, self.state)
+        params = DocumenterBridge(
+            self.env, reporter, documenter_options, lineno, self.state
+        )
         documenter = doccls(params, self.arguments[0])
         documenter.generate(more_content=self.content)
         if not params.result:
             return []
 
-        logger.debug('[sphinxcontrib-matlabdomain] output:\n%s', '\n'.join(params.result))
+        logger.debug(
+            "[sphinxcontrib-matlabdomain] output:\n%s", "\n".join(params.result)
+        )
 
         # record all filenames as dependencies -- this will at least
         # partially make automatic invalidation possible
