@@ -15,27 +15,26 @@ import sys
 import pytest
 
 from sphinx import addnodes
-from sphinx.testing.fixtures import make_app, test_params   # noqa: F811;
+from sphinx.testing.fixtures import make_app, test_params  # noqa: F811;
 from sphinx.testing.path import path
 
 
-@pytest.fixture(scope='module')
+@pytest.fixture(scope="module")
 def rootdir():
     return path(os.path.dirname(__file__)).abspath()
 
 
 @pytest.mark.skipif(sys.version_info < (3, 6), reason="requires python3.6 or higher")
 def test_setup(make_app, rootdir):
-    srcdir = rootdir / 'roots' / 'test_skipping_module_members'
+    srcdir = rootdir / "roots" / "test_skipping_module_members"
     app = make_app(srcdir=srcdir)
     app.builder.build_all()
 
-    content = pickle.loads((app.doctreedir / 'index.doctree').read_bytes())
+    content = pickle.loads((app.doctreedir / "index.doctree").read_bytes())
     content_text = content.astext()
-    assert 'The first function' in content_text
-    assert 'The second function' not in content_text
+    assert "The first function" in content_text
+    assert "The second function" not in content_text
 
 
-
-if __name__ == '__main__':
+if __name__ == "__main__":
     pytest.main([__file__])
